@@ -1,7 +1,7 @@
 /* XPENGUINS - cool little penguins that walk along the tops of your windows
  * -copyright-
 #-# 
-#-# Copyright (C) 1999-2001  Robin Hogan, 2021 Willem Vermin
+#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2024 Willem Vermin
 #-# 
 #-# This program is free software; you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -65,6 +65,8 @@
 #include "ui.h"
 #include "utils.h"
 #include "main.h"
+#include "docs.h"
+#include "selfrep.h"
 
 #define DEFAULT_THEME "Penguins"
 
@@ -78,7 +80,6 @@
    (strcmp(argv[n], long_arg) == 0 || strcmp(argv[n], "-" long_arg) == 0)
 
 /* Prototypes */
-static void ShowUsage(char **argv);
 static void ListThemes();
 static void DescribeThemes(char **theme_names);
 static float LoadAverage();
@@ -186,7 +187,7 @@ int main (int argc, char **argv)
 	 }
 	 else {
 	    fprintf(stderr, _("Error: number of penguins not specified\n"));
-	    ShowUsage(argv);
+	    docs_usage(argv);
 	    exit(1);
 	 }
       }
@@ -196,7 +197,7 @@ int main (int argc, char **argv)
 	 }
 	 else {
 	    fprintf(stderr, _("Error: delay in milliseconds not specified\n"));
-	    ShowUsage(argv);
+	    docs_usage(argv);
 	    exit(1);
 	 }
       }
@@ -206,7 +207,7 @@ int main (int argc, char **argv)
 	 }
 	 else {
 	    fprintf(stderr, _("Error: speed not specified\n"));
-	    ShowUsage(argv);
+	    docs_usage(argv);
 	    exit(1);
 	 }
       }
@@ -216,7 +217,7 @@ int main (int argc, char **argv)
 	 }
 	 else {
 	    fprintf(stderr, _("Error: display not specified\n"));
-	    ShowUsage(argv);
+	    docs_usage(argv);
 	    exit(1);
 	 }
       }
@@ -231,7 +232,7 @@ int main (int argc, char **argv)
       else if (ArgumentIs("-h", "-help")) {
 	 fprintf(stdout, _("XPenguins %s (%s) by %s\n"),
 	       XPENGUINS_VERSION, XPENGUINS_DATE, XPENGUINS_AUTHOR);
-	 ShowUsage(argv);
+	 docs_usage(argv);
 	 exit(0);
       }
       else if (ArgumentIs("-v", "-version")) {
@@ -247,7 +248,7 @@ int main (int argc, char **argv)
 	 }
 	 else {
 	    fprintf(stderr, _("Error: config directory not specified\n"));
-	    ShowUsage(argv);
+	    docs_usage(argv);
 	    exit(1);
 	 }
       }
@@ -278,7 +279,7 @@ int main (int argc, char **argv)
 	 }
 	 else {
 	    fprintf(stderr, _("Error: theme not specified\n"));
-	    ShowUsage(argv);
+	    docs_usage(argv);
 	    exit(1);
 	 }
       }
@@ -321,7 +322,7 @@ int main (int argc, char **argv)
 	 }
 	 else {
 	    fprintf(stderr, _("Error: --lift expects a number\n"));
-	    ShowUsage(argv);
+	    docs_usage(argv);
 	    exit(1);
 	 }
       else if (LongArgumentIs("-id")) {
@@ -337,7 +338,7 @@ int main (int argc, char **argv)
 	 }
 	 else {
 	    fprintf(stderr, _("Error: window ID not specified\n"));
-	    ShowUsage(argv);
+	    docs_usage(argv);
 	    exit(1);
 	 }
       }
@@ -345,28 +346,38 @@ int main (int argc, char **argv)
 	 if (argc > ++n) {
 	    if ((load1 = atof(argv[n])) < 0.0) {
 	       fprintf(stderr, _("Error: load average must be greater than or equal to zero\n"));
-	       ShowUsage(argv);
+	       docs_usage(argv);
 	       exit(1);
 	    }
 	    if (argc > ++n) {
 	       if ((load2 = atof(argv[n])) < load1) {
 		  fprintf(stderr, _("Error: second load average must be greater than or equal to first\n"));
-		  ShowUsage(argv);
+		  docs_usage(argv);
 		  exit(1);
 	       }
 	    }
 	    else {
 	       fprintf(stderr, _("Error: second load average not specified\n"));
-	       ShowUsage(argv);
+	       docs_usage(argv);
 	       exit(1);
 	    }
 	 }
 	 else {
 	    fprintf(stderr, _("Error: no load averages not specified\n"));
-	    ShowUsage(argv);
+	    docs_usage(argv);
 	    exit(1);
 	 }
       }
+      else if(LongArgumentIs("-changelog"))
+      {
+	 docs_changelog();
+	 exit(0);
+      }
+      else if(LongArgumentIs("-selfrep"))
+      {
+	 selfrep();
+	 exit(0);
+      }
       else {
 	 if (xpenguins_verbose) {
 	    fprintf(stderr, _("Warning: \"%s\" not understood - use \"-h\" for "
@@ -526,41 +537,6 @@ void penguins_move()
 }
 
 
-void ShowUsage(char **argv)
-{
-   printf(_("Usage: %s [options]\n"), argv[0]);
-   printf(_("Options:\n"
-	    "  -d, --display        <display>    Send the penguins to specified display\n"
-	    "  -m, --delay          <millisecs>  Set delay between frames\n"));
-   printf(_("  -n, --penguins       <n>          Create <n> penguins (max %d)\n"),
-	 PENGUIN_MAX);
-   printf(_("  -q, --quiet                       Suppress all non-fatal messages\n"
-	    "  -v, --version                     Show version information\n"
-	    "  -h, --help                        Show this message\n"
-	    "      --defaults                    Skip reading from ~/.xpenguinrc\n"
-	    "      --nomenu                      Do not show menu\n"
-	    "      --hidemenu                    Iconify menu at startup\n"
-	    "      --nodoublebuffer              Do not use double buffering\n"
-	    "  -c, --config-dir     <dir>        Look for config files (and themes) in <dir>\n"
-	    "  -p, --ignorepopups                Penguins ignore \"popup\" windows\n"
-	    "  -r, --rectwin                     Regard shaped windows as rectangular\n"
-	    "  -t, --theme          <theme>      Use named <theme>\n"
-	    "  -l, --list-themes                 List available themes\n"
-	    "  -i, --theme-info                  Describe a theme and exit (use with -t)\n"
-	    "  -b, --no-blood                    Do not show any gory images\n"
-	    "  -a, --no-angels                   Do not show any cherubim\n"
-	    "  -s, --squish                      kill penguins with mouse\n"
-	    "      --lift           <n>          Lift penguins window n pixels\n"
-	    "      --all                         Run all available themes simultaneously\n"
-	    "      --random-theme                Choose a random theme\n"
-	    "      --id             <window id>  Send penguins to window with this ID\n"
-	    "      --nice           <ld1> <ld2>  Start killing penguins when load reaches\n"
-	    "                                       <ld1>, kill all if load reches <ld2>\n"
-	    "(\"--\" can be replaced with \"-\" in all cases)\n"
-	    "System data directory: "));
-   printf(PKGDATADIR "\n");
-}
-
 void ListThemes()
 {
    char **theme;
