@@ -1,6 +1,6 @@
 /* -copyright-
 #-# 
-#-# Copyright (C) 1999-2001  Robin Hogan, 2021 Willem Vermin
+#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2024 Willem Vermin
 #-# 
 #-# This program is free software; you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -148,6 +148,11 @@ MODULE_EXPORT void buttoncb(GtkWidget *w, char *data)
 	    n++;
 	    P("add theme n: %d i: %d theme: %s\n",n,i,allthemenames[i]);
 	    ThemeNames = (char **)realloc(ThemeNames,n*sizeof(char*));
+	    if(ThemeNames == NULL)
+	    {
+	       fprintf(stderr,"Realloc error in %s:%d\n",__FILE__,__LINE__);
+	       exit(1);
+	    }
 	    ThemeNames[n-1] = strdup(allthemenames[i]);
 	 }
       }
@@ -155,9 +160,19 @@ MODULE_EXPORT void buttoncb(GtkWidget *w, char *data)
       {
 	 n = 1;
 	 ThemeNames = (char **)realloc(ThemeNames,n*sizeof(char*));
+	 if(ThemeNames == NULL)
+	 {
+	    fprintf(stderr,"Realloc error in %s:%d\n",__FILE__,__LINE__);
+	    exit(1);
+	 }
 	 ThemeNames[0] = strdup(backup_theme);
       }
       ThemeNames = (char **)realloc(ThemeNames,(n+1)*sizeof(char*));
+      if(ThemeNames == NULL)
+      {
+	 fprintf(stderr,"Realloc error in %s:%d\n",__FILE__,__LINE__);
+	 exit(1);
+      }
       ThemeNames[n] = NULL;
       free(backup_theme);
       main_init();
